==> qtjambi-uitools-debuginfo-macos-5.15.24.jar: sources/QtJambiUiTools/QUiLoader_shell.h <==
#ifndef QUILOADER_SHELL_H
#define QUILOADER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtUiTools/quiloader.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdir.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qactiongroup.h>
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QUiLoader_shell : public QUiLoader, public QtJambiShellInterface
{
public:
    QUiLoader_shell(QObject* parent0 = nullptr);
    ~QUiLoader_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QUiLoader_mshell;
    friend class QUiLoader_oshell;
};


class QUiLoader_mshell : public QUiLoader_shell
{
public:
    using QUiLoader_shell::QUiLoader_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QUiLoader_oshell : public QUiLoader_mshell
{
public:
    using QUiLoader_mshell::QUiLoader_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QAction* createAction(QObject* parent0, const QString& name1) override;
    QActionGroup* createActionGroup(QObject* parent0, const QString& name1) override;
    QLayout* createLayout(const QString& className0, QObject* parent1, const QString& name2) override;
    QWidget* createWidget(const QString& className0, QWidget* parent1, const QString& name2) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QUiLoader_access : public QUiLoader
{
    jobject __qt_createAction_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jstring name1);
    jobject __qt_createActionGroup_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jstring name1);
    jobject __qt_createLayout_cref_QString_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring className0, QtJambiNativeID parent1, jstring name2);
    jobject __qt_createWidget_cref_QString_QWidget_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring className0, QtJambiNativeID parent1, jstring name2);
};

#endif // QUILOADER_SHELL_H

==> qtjambi-uitools-debuginfo-macos-6.5.7.jar: sources/QtJambiUiTools/QUiLoader_shell.h <==
#ifndef QUILOADER_SHELL_H
#define QUILOADER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtUiTools/quiloader.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdir.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#if QT_CONFIG(action)
#include <QtGui/qactiongroup.h>
#endif //QT_CONFIG(action)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QUiLoader_shell : public QUiLoader, public QtJambiShellInterface
{
public:
    QUiLoader_shell(QObject* parent0 = nullptr);
    ~QUiLoader_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QUiLoader_mshell;
    friend class QUiLoader_oshell;
};


class QUiLoader_mshell : public QUiLoader_shell
{
public:
    using QUiLoader_shell::QUiLoader_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QUiLoader_oshell : public QUiLoader_mshell
{
public:
    using QUiLoader_mshell::QUiLoader_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QAction* createAction(QObject* parent0, const QString& name1) override;
    QActionGroup* createActionGroup(QObject* parent0, const QString& name1) override;
    QLayout* createLayout(const QString& className0, QObject* parent1, const QString& name2) override;
    QWidget* createWidget(const QString& className0, QWidget* parent1, const QString& name2) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QUiLoader_access : public QUiLoader
{
    jobject __qt_createAction_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jstring name1);
    jobject __qt_createActionGroup_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jstring name1);
    jobject __qt_createLayout_cref_QString_QObject_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring className0, QtJambiNativeID parent1, jstring name2);
    jobject __qt_createWidget_cref_QString_QWidget_ptr_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring className0, QtJambiNativeID parent1, jstring name2);
};

#endif // QUILOADER_SHELL_H
